# -*- coding: utf-8 -*-

RESEARCH_ORG_DOMAINS = {
    'niper.ac.in': [u'National Institute of Pharmaceutical Education and Research'],
    'nyumc.org': [u'NYU Langone Medical Center'],
    'embl.de': [u'European Molecular Biology Laboratory'],
    'erasmusmc.nl': [u'Erasmus University Medical Center'],
    'ncbs.res.in': [u'National Centre for Biological Sciences'],
    'bccrc.ca': [u'BC Cancer Research Centre'],
    'mpimf-heidelberg.mpg.de': [u'Max Planck Institute for Medical Research'],
    'mpg.de': [u'Max Planck Institute'],
    'dkfz-heidelberg.de': [u'German Cancer Research Center'],
    'dkfz.de': [u'German Cancer Research Center'],
    'helmholtz-hzi.de': [u'Helmholtz Centre for Infection Research'],
    'univ-tlse3.fr': [u'Université Paul Sabatier'],
    'santafe-conicet.gov.ar': [u'Instituto de Agrobiotecnología del Litoral'],
}
